<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim/plugins/unreadmessageskeeper/src/unreadmessageskeeper.cpp" line="+32"/>
        <source>Sidorov Aleksey</source>
        <translation>Алексей Сидоров</translation>
    </message>
    <message>
        <source>Aleksey Sidorov</source>
        <translation type="obsolete">Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location line="-4"/>
        <source>UnreadMessagesKeeper</source>
        <translation>Съхраняване на непрочетени съобщения</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Allows you to save a list of unread messages when qutIM exit</source>
        <translation>Позволява съхраняването на списък от непрочетени съобщения при изход от qutIM</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="+4"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
</context>
</TS>
